*******************
fournax
*******************

overview
=============

Fournax is an abbreviation of Fourier numerical astronomy extension, its name is a backronym styled to match the constellation 'fornax'. 

A major future update will bring a more powerful curve fitting function to this sub-package. (2020-09-14+15)

Reference/API
=============

.. automodapi:: dorado.fournax